#include <iostream>  
#include <fstream>  
#include <sstream>   // String stream
using namespace std;

#define MAXPPL 10
#define MAXSTR 200

struct person_record_t
{
	char name[MAXSTR];
	int age;
};

void print_person(person_record_t p)
{
	cout << "Name: " << p.name << endl;
	cout << "Age: " << p.age << endl;
}

void celebrate_birthday(person_record_t &p)
{
	cout << "Happy times" << endl;
	print_person(p);
	cout << "Happy birthday to " << p.name << endl;


	p.age++;
}

void celebrate_birthday_ptr(person_record_t *ptr)
{
	cout << "Happy times (with pointers)" << endl;
	print_person(*ptr);
	cout << "(Pointer version) Happy birthday to " << ptr->name << endl;

	ptr->age++; // Is just a pretty version of (*ptr).age++;
		    // this is syntatical sugar

	// Warning: *ptr.field is actually this *(ptr.field)
}

void read_person(char *inputline, person_record_t &output)
{
	/* Input: takes a string, from our file, called inputline.
	 * Output: produces a person_record_t
	 * Work: splits the input line */

	stringstream ss(inputline);

	ss >> output.name;
	ss >> output.age;
	
}

int main(int argc, char **argv)
{
	/*	
	person_record_t p = {"Alberto", 13};
	print_person(p);
	person_record_t q = {"Jane", 33};
	print_person(q);
	*/


	if (argc != 2) {
		cerr << "Expecting exactly one argument for the file to read!" << endl;
		return 1;
	}


	// cout << "file to open is " << argv[1] << endl;
	ifstream ifs; // stream to read the file from
	ifs.open(argv[1], ios_base::in); 

	if (!ifs) {
		cerr << "Unable to read file \"" << argv[1] << "\"" << endl;
		return 1;

	}


	person_record_t people[MAXPPL];
	char line[MAXSTR];	

	int total_people = 0;
	while (ifs.getline(line, MAXSTR))
	{
		// cout << "Line " << total_people << ": '" << line << "'" << endl;
		read_person(line, people[total_people]);
		total_people++;
		if (total_people >= MAXPPL)
		{
			cerr << "Sorry, your input is too large." << endl;
			ifs.close(); 
			return 1;
		}
	}

	ifs.close();


	// At this point the # of people is stored in total_people
	// And the records are in people[.]

	cout << " ======== ======== ======== ======== ======== " << endl;
	for (int i = 0; i < total_people; i++)
		print_person(people[i]);

	cout << endl;
	celebrate_birthday(people[0]);
	cout << endl;
	celebrate_birthday_ptr( & (people[1]) );

	cout << " ======== ======== ======== ======== ======== " << endl;
	for (int i = 0; i < total_people; i++)
		print_person(people[i]);



	return 0;
}


